#-------------------------------------------------------------------------------
#
# Thomas Thomassen
# thomas[at]thomthom[dot]net
#
#-------------------------------------------------------------------------------

require 'sketchup'
require 'extensions'

#-------------------------------------------------------------------------------

module TT
 module Plugins
  module CleanUp

  ### CONSTANTS ### ------------------------------------------------------------

  # Plugin information
  PLUGIN_ID       = 'TT_CleanUp'.freeze
  PLUGIN_NAME     = 'CleanUp³ - 清理模型'.freeze
  PLUGIN_VERSION  = '3.4.6'.freeze
  PLUGIN_URL      = 'https://extensions.sketchup.com/content/cleanup%C2%B3'.freeze

  # Resource paths
  file = __FILE__.dup
  file.force_encoding('UTF-8') if file.respond_to?(:force_encoding)
  FILENAMESPACE = File.basename(file, '.*')
  PATH_ROOT     = File.dirname(file).freeze
  PATH          = File.join(PATH_ROOT, FILENAMESPACE).freeze


  ### EXTENSION ### ------------------------------------------------------------

  unless file_loaded?(__FILE__)
    loader = File.join(PATH, 'bootstrap')
    @ex = SketchupExtension.new(PLUGIN_NAME, loader)
    @ex.description = '模型的清理和优化操作。'
    @ex.version     = PLUGIN_VERSION
    @ex.copyright   = 'Thomas Thomassen © 2009-2024'
    @ex.creator     = 'Thomas Thomassen (thomas@thomthom.net)'
    Sketchup.register_extension(@ex, true)
  end

    # 以下部分是添加图标的代码
    toolbar = UI::Toolbar.new "CleanUp³- 清理模型"
    cmd = UI::Command.new("CleanUp³- 清理模型") { self.show_cleanup_ui }
    cmd.tooltip = "CleanUp³- 清理模型"
    cmd.status_bar_text = '打开模型清理面板。'
    cmd.small_icon = "tt_cleanup/c.png"
    cmd.large_icon = "tt_cleanup/c.png"
    toolbar = toolbar.add_item cmd
    toolbar.show
    puts cmd.large_icon
    # 以上部分是添加图标的代码
    
    # 以下部分是添加图标的代码
    toolbar = UI::Toolbar.new "CleanUp³- 清理模型"
    cmd = UI::Command.new("CleanUp³- 清理模型") { self.cu_repair_edges }
    cmd.tooltip = "修复直线"
    cmd.status_bar_text = '修复直线，如有选中线、就清理当前选中的部分线，如未选中线、直接对整个模型进行修复直线操作。'
    cmd.small_icon = "tt_cleanup/c1.png"
    cmd.large_icon = "tt_cleanup/c1.png"
    toolbar = toolbar.add_item cmd
    toolbar.show
    puts cmd.large_icon
    # 以上部分是添加图标的代码    

  end # module CleanUp
 end # module Plugins
end # module TT

#-------------------------------------------------------------------------------

file_loaded(__FILE__)

#-------------------------------------------------------------------------------
